pg.ddx.io  pgsql-committers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
pgsql: test_json_parser: Speed up 002_inline.pl
3+ messages / 1 participants
[nested] [flat]

* pgsql: test_json_parser: Speed up 002_inline.pl
@ 2025-10-01 16:51 Jacob Champion <jchampion@postgresql.org>
  0 siblings, 0 replies; 3+ messages in thread

From: Jacob Champion @ 2025-10-01 16:51 UTC (permalink / raw)
  To: pgsql-committers@lists.postgresql.org

test_json_parser: Speed up 002_inline.pl

Some macOS machines are having trouble with 002_inline, which executes
the JSON parser test executables hundreds of times in a nested loop.
Both developer machines and buildfarm critters have shown excessive test
durations, upwards of 20 seconds.

Push the innermost loop of 002_inline, which iterates through differing
chunk sizes, down into the test executable. (I'd eventually like to push
all of the JSON unit tests down into C, but this is an easy win in the
short term.) Testers have reported a speedup between 4-9x.

Reported-by: Robert Haas <robertmhaas@gmail.com>
Suggested-by: Andres Freund <andres@anarazel.de>
Tested-by: Andrew Dunstan <andrew@dunslane.net>
Tested-by: Tom Lane <tgl@sss.pgh.pa.us>
Tested-by: Robert Haas <robertmhaas@gmail.com>
Discussion: https://postgr.es/m/CA%2BTgmobKoG%2BgKzH9qB7uE4MFo-z1hn7UngqAe9b0UqNbn3_XGQ%40mail.gmail.com
Backpatch-through: 17

Branch
------
master

Details
-------
https://git.postgresql.org/pg/commitdiff/fd726b8379a8191da9e74d28761c967eda13f5f2

Modified Files
--------------
src/test/modules/test_json_parser/README           |  10 +-
src/test/modules/test_json_parser/t/002_inline.pl  |  26 ++++-
.../test_json_parser_incremental.c                 | 127 +++++++++++++--------
3 files changed, 106 insertions(+), 57 deletions(-)



^ permalink  raw  reply  [nested|flat] 3+ messages in thread

* pgsql: test_json_parser: Speed up 002_inline.pl
@ 2025-10-01 16:51 Jacob Champion <jchampion@postgresql.org>
  0 siblings, 0 replies; 3+ messages in thread

From: Jacob Champion @ 2025-10-01 16:51 UTC (permalink / raw)
  To: pgsql-committers@lists.postgresql.org

test_json_parser: Speed up 002_inline.pl

Some macOS machines are having trouble with 002_inline, which executes
the JSON parser test executables hundreds of times in a nested loop.
Both developer machines and buildfarm critters have shown excessive test
durations, upwards of 20 seconds.

Push the innermost loop of 002_inline, which iterates through differing
chunk sizes, down into the test executable. (I'd eventually like to push
all of the JSON unit tests down into C, but this is an easy win in the
short term.) Testers have reported a speedup between 4-9x.

Reported-by: Robert Haas <robertmhaas@gmail.com>
Suggested-by: Andres Freund <andres@anarazel.de>
Tested-by: Andrew Dunstan <andrew@dunslane.net>
Tested-by: Tom Lane <tgl@sss.pgh.pa.us>
Tested-by: Robert Haas <robertmhaas@gmail.com>
Discussion: https://postgr.es/m/CA%2BTgmobKoG%2BgKzH9qB7uE4MFo-z1hn7UngqAe9b0UqNbn3_XGQ%40mail.gmail.com
Backpatch-through: 17

Branch
------
REL_18_STABLE

Details
-------
https://git.postgresql.org/pg/commitdiff/8474a3a15056e06ed797530db5419fee8bfd053a

Modified Files
--------------
src/test/modules/test_json_parser/README           |  10 +-
src/test/modules/test_json_parser/t/002_inline.pl  |  26 ++++-
.../test_json_parser_incremental.c                 | 127 +++++++++++++--------
3 files changed, 106 insertions(+), 57 deletions(-)



^ permalink  raw  reply  [nested|flat] 3+ messages in thread

* pgsql: test_json_parser: Speed up 002_inline.pl
@ 2025-10-01 16:51 Jacob Champion <jchampion@postgresql.org>
  0 siblings, 0 replies; 3+ messages in thread

From: Jacob Champion @ 2025-10-01 16:51 UTC (permalink / raw)
  To: pgsql-committers@lists.postgresql.org

test_json_parser: Speed up 002_inline.pl

Some macOS machines are having trouble with 002_inline, which executes
the JSON parser test executables hundreds of times in a nested loop.
Both developer machines and buildfarm critters have shown excessive test
durations, upwards of 20 seconds.

Push the innermost loop of 002_inline, which iterates through differing
chunk sizes, down into the test executable. (I'd eventually like to push
all of the JSON unit tests down into C, but this is an easy win in the
short term.) Testers have reported a speedup between 4-9x.

Reported-by: Robert Haas <robertmhaas@gmail.com>
Suggested-by: Andres Freund <andres@anarazel.de>
Tested-by: Andrew Dunstan <andrew@dunslane.net>
Tested-by: Tom Lane <tgl@sss.pgh.pa.us>
Tested-by: Robert Haas <robertmhaas@gmail.com>
Discussion: https://postgr.es/m/CA%2BTgmobKoG%2BgKzH9qB7uE4MFo-z1hn7UngqAe9b0UqNbn3_XGQ%40mail.gmail.com
Backpatch-through: 17

Branch
------
REL_17_STABLE

Details
-------
https://git.postgresql.org/pg/commitdiff/c3357759080c3f8b02c87b3d5c09411feb6e26d0

Modified Files
--------------
src/test/modules/test_json_parser/README           |  10 +-
src/test/modules/test_json_parser/t/002_inline.pl  |  26 ++++-
.../test_json_parser_incremental.c                 | 129 ++++++++++++++-------
3 files changed, 111 insertions(+), 54 deletions(-)



^ permalink  raw  reply  [nested|flat] 3+ messages in thread


end of thread, other threads:[~2025-10-01 16:51 UTC | newest]

Thread overview: 3+ messages (download: mbox mbox.gz follow: Atom feed)
-- links below jump to the message on this page --
2025-10-01 16:51 pgsql: test_json_parser: Speed up 002_inline.pl Jacob Champion <jchampion@postgresql.org>
2025-10-01 16:51 pgsql: test_json_parser: Speed up 002_inline.pl Jacob Champion <jchampion@postgresql.org>
2025-10-01 16:51 pgsql: test_json_parser: Speed up 002_inline.pl Jacob Champion <jchampion@postgresql.org>

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox